aborted_play <-
  away_team <-
  away_timeouts_remaining <-
  away_total <-
  conv_1pt <-
  conv_2pt <-
  defteam_timeouts_remaining <-
  dome <-
  down <-
  end_of_half <-
  home_receive_2h_ko <-
  ep <-
  era <-
  era0 <-
  era1 <-
  era2 <-
  era3 <-
  era4 <-
  fd_pct <-
  fg_index <-
  fg_make_prob <-
  fg_wp <-
  first_down_prob <-
  gain <-
  game_id <-
  game_seconds_remaining <-
  game_type <-
  go <-
  go_index <-
  go_wp <-
  half_seconds_remaining <-
  home_team <-
  home_timeouts_remaining <-
  home_total <-
  index <-
  index_2pt <-
  make_fg_wp <-
  miss_fg_wp <-
  model_roof <-
  muff <-
  new_prob <-
  original_posteam <-
  outdoors <-
  pass <-
  pct <-
  pct_0 <-
  play_type_nfl <-
  posteam <-
  posteam_spread <-
  posteam_timeouts_remaining <-
  posteam_total <-
  prior_posteam <-
  prob <-
  prob_1pt <-
  pts <-
  punt_index <-
  punt_wp <-
  qtr <-
  quarter_seconds_remaining <-
  receive_2h_ko <-
  retractable <-
  roof <-
  runoff <-
  rush <-
  score_differential <-
  season <-
  series <-
  spread_line <-
  total_line <-
  turnover <-
  type <-
  value <-
  vegas_wp <-
  vegas_home_wp <-
  week <-
  wp_0 <-
  wp_1 <-
  wp_2 <-
  wp_fail <-
  wp_go1 <-
  wp_go2 <-
  wp_succeed <-
  wp_td <-
  wt_wp <-
  yardline_100 <-
  yardline_after <-
  ydstogo <-
  choice <-
  choice_prob <-
  extra_point_result <-
  fail_wp <-
  go_boost <-
  max_non_go <-
  play_no <-
  punt_prob <-
  success_prob <-
  success_wp <-
  two_point_conv_result <-
  away_score <-
  away_timeout_used <-
  challenge_team <-
  clock_display_value <-
  defteam <-
  espn <-
  espn_id <-
  half <-
  home_opening_kickoff <-
  home_score <-
  home_timeout_used <-
  mins <-
  period_number <-
  play_min <-
  play_sec <-
  play_time <-
  season_type <-
  secs <-
  start_distance <-
  start_down <-
  start_possession_text <-
  start_yards_to_endzone <-
  team.abbreviation <-
  team_abbreviation <-
  temp_yardline <-
  text <-
  time <-
  timeout_team <-
  total_away_timeouts_used <-
  total_home_timeouts_used <-
  type_text <-
  yardline <-
  yardline_number <-
  yardline_side <-
  aborted_play <- NULL
